| dtsmart_lite | R Documentation |
Forces a compact, clean grid view of a dataset by disabling heavy analytics features like advanced filtering, code exports, and header summary statistics.
dtsmart_lite(data, title = NULL, ...)
dtsmartr_lite(data, title = NULL, ...)
data |
A |
title |
Custom string title/name representing the dataset. |
... |
Additional arguments passed to |
An object of class htmlwidget (and sub-class dtsmartr) representing
the interactive compact grid.
if (interactive()) {
dtsmart_lite(mtcars, title = "Mtcars Compact")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.