| dtsmartr-shiny | R Documentation |
Output and render functions for using dtsmartr within Shiny applications and interactive Rmd documents.
dtsmartrOutput(outputId, width = "100%", height = "400px")
renderDtsmartr(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height |
Must be a valid CSS unit (like |
expr |
An expression that generates a dtsmartr |
env |
The environment in which to evaluate |
quoted |
Is |
dtsmartrOutput returns a Shiny output element of class shiny.tag.list
that can be placed in a Shiny user interface.
renderDtsmartr returns a Shiny render function of class shiny.render.function
that can be assigned to an output slot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.