Forces a compact, clean grid view of a dataset by disabling heavy analytics features like advanced filtering, code exports, and header summary statistics.
Arguments
- data
A
data.frameto explore.- title
Custom string title/name representing the dataset.
- ...
Additional arguments passed to
dtsmartr().
Value
An object of class htmlwidget (and sub-class dtsmartr) representing
the interactive compact grid.
Examples
if (interactive()) {
dtsmart_lite(mtcars, title = "Mtcars Compact")
}