| dtsmartr | R Documentation |
Renders a high-performance, virtualized data grid powered by React to explore datasets, filter dynamically, and generate reproducible queries.
dtsmartr(
data,
width = NULL,
height = NULL,
elementId = NULL,
datasetName = NULL,
options = dtsmartr_options(),
skip_routing = FALSE
)
data |
A |
width |
Widget width. Defaults to |
height |
Widget height. Defaults to |
elementId |
CSS ID for the widget container. |
datasetName |
Custom string name representing the dataset in generated reproducible code. If omitted, automatically extracts the R variable name. |
options |
Named list of UI options generated by |
skip_routing |
Logical. Internal flag used by |
An object of class htmlwidget (and sub-class dtsmartr) representing
the interactive virtualized grid. In interactive R sessions, this will
display the explorer in the RStudio/Positron Viewer pane or system browser.
if (interactive()) {
dtsmartr(mtcars, options = dtsmartr_options(hidden_columns = "cyl"))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.