| dtsmartr_options | R Documentation |
Helper function to specify UI customization, initial grid visibility states, and rendering options for the dtsmartr interactive grid widget.
dtsmartr_options(
advanced_filter = TRUE,
show_labels = TRUE,
column_picker = TRUE,
allow_export = TRUE,
theme = "auto",
na_string = "NA",
hidden_columns = NULL,
header_summary = TRUE,
header_density = "auto",
row_density = "standard"
)
advanced_filter |
Logical. If |
show_labels |
Logical. If |
column_picker |
Logical. If |
allow_export |
Logical. If |
theme |
Character. Specifies the UI color theme: |
na_string |
Character. Custom string placeholder displayed in cells with missing values ( |
|
Character vector. Vector of column names to hide by default on initial widget rendering. | |
header_summary |
Logical. If |
header_density |
Character. Density mode for column headers: |
row_density |
Character. Density mode for rows: |
A named list of validated configuration settings.
dtsmartr_options(advanced_filter = FALSE, hidden_columns = c("STUDYID", "USUBJID"))
dtsmartr_options(header_summary = FALSE)
dtsmartr_options(header_density = "minimal", row_density = "compact")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.